{
  inputs = {
    nixpkgs.url = "flake:nixpkgs/nixos-21.11";
    nixpkgs-unstable.url = "flake:nixpkgs/nixos-unstable";
    utils.url = "github:gytis-ivaskevicius/flake-utils-plus/v1.3.1";
    simple-nixos-mailserver = {
      url = "gitlab:simple-nixos-mailserver/nixos-mailserver/nixos-21.05";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    dogetipbot-telegram = {
      url = "gitlab:nyanloutre/dogetipbot-telegram/master";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    ipmihddtemp = {
      url = "gitlab:nyanloutre/ipmihddtemp/master";
      inputs.nixpkgs.follows = "nixpkgs-unstable";
    };
  };

  outputs = inputs@{ self, utils, nixpkgs, nixpkgs-unstable, simple-nixos-mailserver, dogetipbot-telegram, ipmihddtemp }: utils.lib.mkFlake {

    inherit self inputs;

    supportedSystems = [ "x86_64-linux" ];

    channels.nixpkgs.patches = [
      (nixpkgs.legacyPackages."x86_64-linux".fetchpatch {
        name = "fix-homeassistant.patch";
        url = "https://github.com/NixOS/nixpkgs/commit/8e87ea556605e6947d1edb7cd81e58814eeadcae.patch";
        sha256 = "sha256-au5JwwmdRBsbiG9H8nh5n56QVZUFajx1ALMtzu+Nfq0=";
      })
    ];

    hostDefaults.modules = [
      nixpkgs.nixosModules.notDetected
      {
        nix.generateRegistryFromInputs = true;
        nix.linkInputs = true;
        nix.generateNixPathFromInputs = true;
      }
    ];

    hosts.loutreos.modules = [
      simple-nixos-mailserver.nixosModule
      dogetipbot-telegram.nixosModule
      ipmihddtemp.nixosModule
      ./systems/LoutreOS/configuration.nix
    ];

    hosts.paul-fixe = {
      channelName = "nixpkgs-unstable";
      modules = [
        ./systems/PC-Fixe/configuration.nix
      ];
    };
  };
}

